@@ -346,7 +346,7 @@ TEOFILE *TeoCreateNonGzFileWithUserExtension(char *filename,
       return NULL;
     }
     for(i=0;i<extc;i++){
-      if((teofp->extv[i] = (char *)malloc(sizeof(char)*strlen(extv[i])))
+      if((teofp->extv[i] = (char *)malloc(sizeof(char)*strlen(extv[i])+1))
 	 == NULL) {
 	TeoSetErrorMessage(TEO_ER_CREATE_NOT_ENOUGHT_MEMORY);
 	return NULL;
@@ -441,7 +441,7 @@ TEOFILE *TeoCreateGzFileWithUserExtension(char *filename,
       return NULL;
     }
     for(i=0;i<extc;i++){
-      if((teofp->extv[i] = (char *)malloc(sizeof(char)*strlen(extv[i])))
+      if((teofp->extv[i] = (char *)malloc(sizeof(char)*strlen(extv[i])+1))
 	 == NULL) {
 	TeoSetErrorMessage(TEO_ER_CREATE_NOT_ENOUGHT_MEMORY);
 	return NULL;
