@@ -34,10 +34,15 @@
     interpreted as representing official policies, either expressed
     or implied, of Takekazu KATO.
 
-  $Id: teo.h,v 2.1.2.1 2001/12/26 05:50:30 tkato Exp $
+  $Id: teo.h,v 2.1.2.4 2002/04/02 06:54:13 tkato Exp $
 */
 #ifndef _TEO_H_
 #define _TEO_H_
+
+#ifdef __cplusplus
+extern "C" {
+#endif 
+
 #include <stdio.h>
 #include <stddef.h>
 /*****************************************************************************
@@ -49,7 +54,7 @@
 #endif
 /* TEO Image Library Version Number */
 #ifndef TEO_LIB_VERSION
-#define TEO_LIB_VERSION "TEO library $Name: Release-1_2_2 $"
+#define TEO_LIB_VERSION "TEO library $Name:  $"
 #endif
 /*****************************************************************************
                      class definition
@@ -68,7 +73,6 @@ typedef float            TEO_FLOAT32;
 typedef double           TEO_FLOAT64;
 /* ------------------------------------------------------------------ */
 
-
 /* TEOFILE (file infomation for TEO format) */
 typedef struct{
   /* TEO format header info */
@@ -299,7 +303,7 @@ TeoCreateGzFileWithUserExtension((filename),\
 				 (teofp)->extc,(teofp)->extv)
 
 TEOFILE *PnmCreateFile(char *filename,int width,int height,
-		   int type,int bit,int plane);
+		       int type,int bit,int plane);
 
 #define PnmCreateSimilarFile(filename,teofp)\
 PnmCreateFile((filename),\
@@ -348,6 +352,36 @@ TeoCreateFileWithUserExtension((filename),\
 
 int TeoCloseFile(TEOFILE *teofp);
 
+#define TeoNewSimilarFile(filename,teofp) \
+  TeoCreateFileWithUserExtension((filename),\
+			       (teofp)->width,(teofp)->height,\
+			       (teofp)->xoffset,(teofp)->yoffset,\
+			       (teofp)->type,(teofp)->bit,\
+			       (teofp)->plane,(teofp)->frame,\
+			       (teofp)->extc,(teofp)->extv)
+#define TeoNewFile(filename,width,height,xoffset,yoffset,plane,frame,ETYPE) \
+TeoNewFileWithUserExtension(filename,width,height,xoffset,yoffset,plane,frame,0,NULL,ETYPE)
+#define TeoNewFileWithUserExtension(filename,width,height,xoffset,yoffset,plane,frame,extc,extv,ETYPE) \
+TeoNewFileWithUserExtension##ETYPE(filename,width,height,xoffset,yoffset,plane,frame,extc,extv)
+#define TeoNewFileWithUserExtensionTEO_BIT(filename,width,height,xoffset,yoffset,plane,frame,extc,extv) \
+TeoCreateFile(filename,width,height,xoffset,TEO_UNSIGNE,1,plane,frame,extc,extv)
+#define TeoNewFileWithUserExtensionTEO_UINT8(filename,width,height,xoffset,yoffset,plane,frame,extc,extv) \
+TeoCreateFile(filename,width,height,xoffset,TEO_UNSIGNED,8,plane,frame,extc,extv)
+#define TeoNewFileWithUserExtensionTEO_SINT8(filename,width,height,xoffset,yoffset,plane,frame,extc,extv) \
+TeoCreateFile(filename,width,height,xoffset,TEO_SIGNED,8,plane,frame,extc,extv)
+#define TeoNewFileWithUserExtensionTEO_UINT16(filename,width,height,xoffset,yoffset,plane,frame,extc,extv) \
+TeoCreateFile(filename,width,height,xoffset,TEO_UNSIGNED,16,plane,frame,extc,extv)
+#define TeoNewFileWithUserExtensionTEO_SINT16(filename,width,height,xoffset,yoffset,plane,frame,extc,extv) \
+TeoCreateFile(filename,width,height,xoffset,TEO_SIGNED,16,plane,frame,extc,extv)
+#define TeoNewFileWithUserExtensionTEO_UINT32(filename,width,height,xoffset,yoffset,plane,frame,extc,extv) \
+TeoCreateFile(filename,width,height,xoffset,TEO_UNSIGNED,32,plane,frame,extc,extv)
+#define TeoNewFileWithUserExtensionTEO_SINT32(filename,width,height,xoffset,yoffset,plane,frame,extc,extv) \
+TeoCreateFile(filename,width,height,xoffset,TEO_SIGNED,32,plane,frame,extc,extv)
+#define TeoNewFileWithUserExtensionTEO_FLOAT32(filename,width,height,xoffset,yoffset,plane,frame,extc,extv) \
+TeoCreateFile(filename,width,height,xoffset,TEO_FLOAT,32,plane,frame,extc,extv)
+#define TeoNewFileWithUserExtensionTEO_FLOAT64(filename,width,height,xoffset,yoffset,plane,frame,extc,extv) \
+TeoCreateFile(filename,width,height,xoffset,TEO_FLOAT,64,plane,frame,extc,extv)
+
 /* file access functions */
 /* read one frame from TEO file */
 int TeoReadFrame(TEOFILE *teofp,TEOIMAGE *image);
@@ -416,6 +450,45 @@ int TeoFreeImage(TEOIMAGE *image);
 	     (index_p)))\
 	  | (0x01 << (7 - (((index_x) - (image)->xoffset) % 8))))))
 
+
+#define TeoGetPixelValue(image,index_x,index_y,index_p,ETYPE)\
+TeoGetPixel##ETYPE(image,index_x,index_y,index_p)
+#define TeoPutPixelValue(image,index_x,index_y,index_p,ETYPE,val)\
+TeoPutPixel##ETYPE(image,index_x,index_y,index_p,val)
+
+#define TeoGetPixelTEO_BIT(image,index_x,index_y,index_p)\
+TeoGetBit(image,index_x,index_y,index_p)
+#define TeoPutPixelTEO_BIT(image,index_x,index_y,index_p,val)\
+TeoGetBit(image,index_x,index_y,index_p,val)
+#define TeoGetPixelTEO_UINT8(image,index_x,index_y,index_p)\
+TeoGetPixel(image,index_x,index_y,index_p,TEO_UINT8)
+#define TeoPutPixelTEO_UINT8(image,index_x,index_y,index_p,val)\
+TeoGetPixel(image,index_x,index_y,index_p,TEO_UINT8,val)
+#define TeoGetPixelTEO_SINT8(image,index_x,index_y,index_p)\
+TeoGetPixel(image,index_x,index_y,index_p,TEO_SINT8)
+#define TeoPutPixelTEO_SINT8(image,index_x,index_y,index_p,val)\
+TeoGetPixel(image,index_x,index_y,index_p,TEO_SINT8,val)
+#define TeoGetPixelTEO_UINT16(image,index_x,index_y,index_p)\
+TeoGetPixel(image,index_x,index_y,index_p,TEO_UINT16)
+#define TeoPutPixelTEO_UINT16(image,index_x,index_y,index_p,val)\
+TeoGetPixel(image,index_x,index_y,index_p,TEO_UINT16,val)
+#define TeoGetPixelTEO_SINT16(image,index_x,index_y,index_p)\
+TeoGetPixel(image,index_x,index_y,index_p,TEO_SINT16)
+#define TeoPutPixelTEO_SINT16(image,index_x,index_y,index_p,val)\
+TeoGetPixel(image,index_x,index_y,index_p,TEO_SINT16,val)
+#define TeoGetPixelTEO_UINT32(image,index_x,index_y,index_p)\
+TeoGetPixel(image,index_x,index_y,index_p,TEO_UINT32)
+#define TeoPutPixelTEO_UINT32(image,index_x,index_y,index_p,val)\
+TeoGetPixel(image,index_x,index_y,index_p,TEO_UINT32,val)
+#define TeoGetPixelTEO_FLOAT32(image,index_x,index_y,index_p)\
+TeoGetPixel(image,index_x,index_y,index_p,TEO_FLOAT32)
+#define TeoPutPixelTEO_FLOAT32(image,index_x,index_y,index_p,val)\
+TeoGetPixel(image,index_x,index_y,index_p,TEO_FLOAT32,val)
+#define TeoGetPixelTEO_FLOAT64(image,index_x,index_y,index_p)\
+TeoGetPixel(image,index_x,index_y,index_p,TEO_FLOAT64)
+#define TeoPutPixelTEO_FLOAT64(image,index_x,index_y,index_p,val)\
+TeoGetPixel(image,index_x,index_y,index_p,TEO_FLOAT64,val)
+
 /* convenience macros */
 /* access member of structure TEOFILE or TEOIMAGE */
 #define TeoWidth(info)   ((info)->width)
@@ -463,6 +536,27 @@ int TeoFreeImage(TEOIMAGE *image);
 #define TeoIsFLOAT64(info)\
      (((info)->bit == 64) && ((info)->type == TEO_FLOAT))
 
+#define TeoCheckPixelType(info,ETYPE)\
+TeoIs##ETYPE(info)
+#define TeoIsTEO_BIT(info)\
+     ((info)->bit == 1)
+#define TeoIsTEO_UINT8(info)\
+     (((info)->bit == 8) && ((info)->type == TEO_UNSIGNED))
+#define TeoIsTEO_SINT8(info)\
+     (((info)->bit == 8) && ((info)->type == TEO_SIGNED))
+#define TeoIsTEO_UINT16(info)\
+     (((info)->bit == 16) && ((info)->type == TEO_UNSIGNED))
+#define TeoIsTEO_SINT16(info)\
+     (((info)->bit == 16) && ((info)->type == TEO_SIGNED))
+#define TeoIsTEO_UINT32(info)\
+     (((info)->bit == 32) && ((info)->type == TEO_UNSIGNED))
+#define TeoIsTEO_SINT32(info)\
+     (((info)->bit == 32) && ((info)->type == TEO_SIGNED))
+#define TeoIsTEO_FLOAT32(info)\
+     (((info)->bit == 32) && ((info)->type == TEO_FLOAT))
+#define TeoIsTEO_FLOAT64(info)\
+     (((info)->bit == 64) && ((info)->type == TEO_FLOAT))
+
 #define TeoCheckFrame(info) ((info)->current < (info)->frame)
 
 
@@ -491,6 +585,9 @@ int TeoFreeImage(TEOIMAGE *image);
 /* access member of structure TEOIMAGE */
 #define teo_data(info)    TeoData(info)
 
+#ifdef __cplusplus
+}
+#endif 
 /*****************************************************************************
                      Debug Mode
 ******************************************************************************/
